r46537 - in /desktop/unstable/gnome-keyring/debian: changelog patches/fork_before_using_dbus.patch
mitya57 at users.alioth.debian.org
mitya57 at users.alioth.debian.org
Mon Oct 12 19:33:53 UTC 2015
Author: mitya57
Date: Mon Oct 12 19:33:53 2015
New Revision: 46537
URL: http://svn.debian.org/wsvn/pkg-gnome/?sc=1&rev=46537
Log:
Update fork_before_using_dbus.patch to make sure it does not break the
testsuite (should fix the build failure).
Modified:
desktop/unstable/gnome-keyring/debian/changelog
desktop/unstable/gnome-keyring/debian/patches/fork_before_using_dbus.patch
Modified: desktop/unstable/gnome-keyring/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-gnome/desktop/unstable/gnome-keyring/debian/changelog?rev=46537&op=diff
==============================================================================
--- desktop/unstable/gnome-keyring/debian/changelog [utf-8] (original)
+++ desktop/unstable/gnome-keyring/debian/changelog [utf-8] Mon Oct 12 19:33:53 2015
@@ -1,3 +1,10 @@
+gnome-keyring (3.18.0-4) unstable; urgency=medium
+
+ * Update fork_before_using_dbus.patch to make sure it does not break the
+ testsuite (should fix the build failure).
+
+ -- Dmitry Shachnev <mitya57 at debian.org> Mon, 12 Oct 2015 22:29:57 +0300
+
gnome-keyring (3.18.0-3) unstable; urgency=medium
[ Michael Biebl ]
Modified: desktop/unstable/gnome-keyring/debian/patches/fork_before_using_dbus.patch
URL: http://svn.debian.org/wsvn/pkg-gnome/desktop/unstable/gnome-keyring/debian/patches/fork_before_using_dbus.patch?rev=46537&op=diff
==============================================================================
--- desktop/unstable/gnome-keyring/debian/patches/fork_before_using_dbus.patch [utf-8] (original)
+++ desktop/unstable/gnome-keyring/debian/patches/fork_before_using_dbus.patch [utf-8] Mon Oct 12 19:33:53 2015
@@ -1,11 +1,16 @@
Description: be careful to avoid spinning a main loop before fork()
Author: Cosimo Cecchi <cosimo.cecchi at gmail.com>
-Forwarded: https://bugzilla.gnome.org/show_bug.cgi?id=756059#c5
+Forwarded: https://bugzilla.gnome.org/show_bug.cgi?id=756059#c10
Last-Update: 2015-10-12
--- a/daemon/gkd-main.c
+++ b/daemon/gkd-main.c
-@@ -609,10 +609,8 @@
+@@ -605,14 +605,12 @@
+ }
+
+ static void
+-fork_and_print_environment (void)
++fork_daemon (void)
{
int status;
pid_t pid;
@@ -70,7 +75,7 @@
+ signal (SIGPIPE, SIG_IGN);
+
+ /* The whole forking and daemonizing dance starts here. */
-+ fork_and_print_environment();
++ fork_daemon ();
+
+ /* Prepare logging a second time, since we may be in a different process */
+ prepare_logging();
@@ -78,11 +83,11 @@
/* The --start option */
if (run_for_start) {
if (discover_other_daemon (initialize_daemon_at, TRUE)) {
-@@ -898,6 +897,16 @@
- g_message ("Could not find daemon to replace, staring normally");
- }
+@@ -901,6 +900,16 @@
+ /* Initialize the main directory */
+ gkd_util_init_master_directory (control_directory);
-+ /* Here we are in the resulting daemon or background process. */
++ /* Here we are in the resulting process. */
+ print_environment ();
+
+ if (!run_foreground)
@@ -92,8 +97,8 @@
+ close (fd);
+ }
+
- /* Initialize the main directory */
- gkd_util_init_master_directory (control_directory);
+ /* Initialize our daemon main loop and threading */
+ loop = g_main_loop_new (NULL, FALSE);
@@ -908,11 +917,6 @@
if (!gkd_control_listen ())
More information about the pkg-gnome-commits
mailing list